@@ -2,6 +2,7 @@ import enum
 import base64
 import enum
 import hashlib
+import io
 import json
 import random
 import re
@@ -74,6 +75,10 @@ class Utils:
 
         return round(abs(value))
 
+    @staticmethod
+    def datetime_now_format(output_format: str = "%d/%m/%Y %H:%M:%S"):
+        return Utils.datetime_now().strftime(output_format)
+
     @staticmethod
     def format_datetime(in_datetime: Union[str, datetime]) -> Optional[datetime]:
         if not in_datetime:
@@ -432,6 +437,14 @@ class FileUtils:
         file.file.seek(0)  # Reset to beginning
         return size
 
+    @staticmethod
+    def create_upload_file(path: str, filename: str = None, content_type: str = None) -> UploadFile:
+
+        with open(path, "rb") as f:
+            content = f.read()
+        stream = io.BytesIO(content)
+        return UploadFile(filename=filename or path.split("/")[-1], file=stream, headers={"content_type": content_type})
+
 
 class Base64Utils:
     @staticmethod
